==> bem-components-3.1.2.tgz: package/common.blocks/dropdown/dropdown.js <==
/**
 * @module dropdown
 */

modules.define(
    'dropdown',
    ['i-bem__dom', 'popup'],
    function(provide, BEMDOM) {

/**
 * @exports
 * @class dropdown
 * @bem
 *
 * @bemmod opened Represents opened state
 */
provide(BEMDOM.decl(this.name, /** @lends dropdown.prototype */{
    beforeSetMod : {
        'opened' : {
            'true' : function() {
                if(this.hasMod('disabled')) return false;
            }
        }
    },

    onSetMod : {
        'js' : {
            'inited' : function() {
                this._switcher = null;
                this._popup = null;
            }
        },

        'opened' : function(_, modVal) {
            this.getPopup().setMod('visible', modVal);
            this._switcher.domElem.attr('aria-expanded', !!modVal);
        },

        'disabled' : {
            '*' : function(modName, modVal) {
                this.getSwitcher().setMod(modName, modVal);
            },

            'true' : function() {
                this.getPopup().delMod('visible');
            }
        }
    },

    /**
     * Returns popup
     * @returns {popup}
     */
    getPopup : function() {
        return this._popup ||
            (this._popup = this.findBlockOn('popup')
                .setAnchor(this.getSwitcher())
                .on({ modName : 'visible', modVal : '*' }, this._onPopupVisibilityChange, this));
    },

    /**
     * Returns switcher
     * @returns {i-bem__dom}
     */
    getSwitcher : function() {
        return this._switcher ||
            (this._switcher = this.findBlockOn(this.getMod('switcher')));
    },

    /**
     * On BEM click event handler
     * @param {events:Event} e
     * @protected
     */
    onSwitcherClick : function(e) {
        this._switcher || (this._switcher = e.target);
        this.toggleMod('opened');
    },

    _onPopupVisibilityChange : function(_, data) {
        this.setMod('opened', data.modVal);
    }
}, /** @lends dropdown */{
    live : true
}));

});

==> bem-components-5.0.0.tgz: package/common.blocks/dropdown/dropdown.js <==
/**
 * @module dropdown
 */

modules.define(
    'dropdown',
    ['i-bem-dom', 'popup'],
    function(provide, bemDom, Popup) {

/**
 * @exports
 * @class dropdown
 * @bem
 *
 * @bemmod opened Represents opened state
 */
provide(bemDom.declBlock(this.name, /** @lends dropdown.prototype */{
    beforeSetMod : {
        'opened' : {
            'true' : function() {
                if(this.hasMod('disabled')) return false;
            }
        }
    },

    onSetMod : {
        'js' : {
            'inited' : function() {
                this._switcher = null;
                this._popup = null;
            }
        },

        'opened' : function(_, modVal) {
            this.getPopup().setMod('visible', modVal);
            this._switcher.domElem.attr('aria-expanded', !!modVal);
        },

        'disabled' : {
            '*' : function(modName, modVal) {
                this.getSwitcher().setMod(modName, modVal);
            },

            'true' : function() {
                this.getPopup().delMod('visible');
            }
        }
    },

    /**
     * Returns popup
     * @returns {popup}
     */
    getPopup : function() {
        if(this._popup) return this._popup;

        this._popup = this.findMixedBlock(Popup).setAnchor(this.getSwitcher());
        this._popup._events().on({ modName : 'visible', modVal : '*' }, this._onPopupVisibilityChange, this);
        return this._popup;
    },

    /**
     * Returns switcher
     * @returns {i-bem-dom}
     */
    getSwitcher : function() {
        return this._switcher ||
            (this._switcher = this.findMixedBlock(this._getSwitcherClass()));
    },

    _getSwitcherClass : function() {
        return bemDom.declBlock(this.getMod('switcher'));
    },

    /**
     * On BEM click event handler
     * @param {events:Event} e
     * @protected
     */
    onSwitcherClick : function(e) {
        this._switcher || (this._switcher = e.target);
        this.toggleMod('opened');
    },

    _onPopupVisibilityChange : function(_, data) {
        this.setMod('opened', data.modVal);
    }
}, /** @lends dropdown */{
    lazyInit : true
}));

});
